Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Tunnel ¶
type Tunnel struct {
// contains filtered or unexported fields
}
Tunnel represents an SSH tunnel that forwards a local port to a remote MySQL server.
func NewTunnel ¶
NewTunnel establishes an SSH tunnel and returns a Tunnel that forwards connections from a random local port to remoteHost:remotePort through the SSH server.
Click to show internal directories.
Click to hide internal directories.